/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ChronicleRuleDeploymentConfig extends cdktf.TerraformMetaArguments {
    /**
    * Whether detections resulting from this deployment should be considered
    * alerts.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment#alerting ChronicleRuleDeployment#alerting}
    */
    readonly alerting?: boolean | cdktf.IResolvable;
    /**
    * The archive state of the rule deployment.
    * Cannot be set to true unless enabled is set to false i.e.
    * archiving requires a two-step process: first, disable the rule by
    * setting 'enabled' to false, then set 'archive' to true.
    * If set to true, alerting will automatically be set to false.
    * If currently set to true, enabled, alerting, and run_frequency cannot be
    * updated.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment#archived ChronicleRuleDeployment#archived}
    */
    readonly archived?: boolean | cdktf.IResolvable;
    /**
    * Whether the rule is currently deployed continuously against incoming data.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment#enabled ChronicleRuleDeployment#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment#id ChronicleRuleDeployment#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The unique identifier for the Chronicle instance, which is the same as the customer ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment#instance ChronicleRuleDeployment#instance}
    */
    readonly instance: string;
    /**
    * The location of the resource. This is the geographical region where the Chronicle instance resides, such as "us" or "europe-west2".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment#location ChronicleRuleDeployment#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment#project ChronicleRuleDeployment#project}
    */
    readonly project?: string;
    /**
    * The Rule ID of the rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment#rule ChronicleRuleDeployment#rule}
    */
    readonly rule: string;
    /**
    * The run frequency of the rule deployment.
    * Possible values:
    * LIVE
    * HOURLY
    * DAILY
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment#run_frequency ChronicleRuleDeployment#run_frequency}
    */
    readonly runFrequency?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment#timeouts ChronicleRuleDeployment#timeouts}
    */
    readonly timeouts?: ChronicleRuleDeploymentTimeouts;
}
export interface ChronicleRuleDeploymentTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment#create ChronicleRuleDeployment#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment#delete ChronicleRuleDeployment#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment#update ChronicleRuleDeployment#update}
    */
    readonly update?: string;
}
export declare function chronicleRuleDeploymentTimeoutsToTerraform(struct?: ChronicleRuleDeploymentTimeouts | cdktf.IResolvable): any;
export declare function chronicleRuleDeploymentTimeoutsToHclTerraform(struct?: ChronicleRuleDeploymentTimeouts | cdktf.IResolvable): any;
export declare class ChronicleRuleDeploymentTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ChronicleRuleDeploymentTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: ChronicleRuleDeploymentTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment google_chronicle_rule_deployment}
*/
export declare class ChronicleRuleDeployment extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_chronicle_rule_deployment";
    /**
    * Generates CDKTF code for importing a ChronicleRuleDeployment resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ChronicleRuleDeployment to import
    * @param importFromId The id of the existing ChronicleRuleDeployment that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ChronicleRuleDeployment to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/chronicle_rule_deployment google_chronicle_rule_deployment} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ChronicleRuleDeploymentConfig
    */
    constructor(scope: Construct, id: string, config: ChronicleRuleDeploymentConfig);
    private _alerting?;
    get alerting(): boolean | cdktf.IResolvable;
    set alerting(value: boolean | cdktf.IResolvable);
    resetAlerting(): void;
    get alertingInput(): boolean | cdktf.IResolvable | undefined;
    get archiveTime(): string;
    private _archived?;
    get archived(): boolean | cdktf.IResolvable;
    set archived(value: boolean | cdktf.IResolvable);
    resetArchived(): void;
    get archivedInput(): boolean | cdktf.IResolvable | undefined;
    get consumerRules(): string[];
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    get executionState(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _instance?;
    get instance(): string;
    set instance(value: string);
    get instanceInput(): string | undefined;
    get lastAlertStatusChangeTime(): string;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    get producerRules(): string[];
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _rule?;
    get rule(): string;
    set rule(value: string);
    get ruleInput(): string | undefined;
    private _runFrequency?;
    get runFrequency(): string;
    set runFrequency(value: string);
    resetRunFrequency(): void;
    get runFrequencyInput(): string | undefined;
    private _timeouts;
    get timeouts(): ChronicleRuleDeploymentTimeoutsOutputReference;
    putTimeouts(value: ChronicleRuleDeploymentTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | ChronicleRuleDeploymentTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
