/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface EventarcEnrollmentConfig extends cdktf.TerraformMetaArguments {
    /**
    * Resource annotations.
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#annotations EventarcEnrollment#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * A CEL expression identifying which messages this enrollment applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#cel_match EventarcEnrollment#cel_match}
    */
    readonly celMatch: string;
    /**
    * Destination is the Pipeline that the Enrollment is delivering to. It must
    * point to the full resource name of a Pipeline. Format:
    * "projects/{PROJECT_ID}/locations/{region}/pipelines/{PIPELINE_ID)"
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#destination EventarcEnrollment#destination}
    */
    readonly destination: string;
    /**
    * Resource display name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#display_name EventarcEnrollment#display_name}
    */
    readonly displayName?: string;
    /**
    * The user-provided ID to be assigned to the Enrollment. It should match the
    * format '^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#enrollment_id EventarcEnrollment#enrollment_id}
    */
    readonly enrollmentId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#id EventarcEnrollment#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Resource labels.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#labels EventarcEnrollment#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Resource ID segment making up resource 'name'. It identifies the resource within its parent collection as described in https://google.aip.dev/122.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#location EventarcEnrollment#location}
    */
    readonly location: string;
    /**
    * Resource name of the message bus identifying the source of the messages. It
    * matches the form
    * projects/{project}/locations/{location}/messageBuses/{messageBus}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#message_bus EventarcEnrollment#message_bus}
    */
    readonly messageBus: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#project EventarcEnrollment#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#timeouts EventarcEnrollment#timeouts}
    */
    readonly timeouts?: EventarcEnrollmentTimeouts;
}
export interface EventarcEnrollmentTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#create EventarcEnrollment#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#delete EventarcEnrollment#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#update EventarcEnrollment#update}
    */
    readonly update?: string;
}
export declare function eventarcEnrollmentTimeoutsToTerraform(struct?: EventarcEnrollmentTimeouts | cdktf.IResolvable): any;
export declare function eventarcEnrollmentTimeoutsToHclTerraform(struct?: EventarcEnrollmentTimeouts | cdktf.IResolvable): any;
export declare class EventarcEnrollmentTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): EventarcEnrollmentTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: EventarcEnrollmentTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment google_eventarc_enrollment}
*/
export declare class EventarcEnrollment extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_eventarc_enrollment";
    /**
    * Generates CDKTF code for importing a EventarcEnrollment resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the EventarcEnrollment to import
    * @param importFromId The id of the existing EventarcEnrollment that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the EventarcEnrollment to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/eventarc_enrollment google_eventarc_enrollment} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options EventarcEnrollmentConfig
    */
    constructor(scope: Construct, id: string, config: EventarcEnrollmentConfig);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    private _celMatch?;
    get celMatch(): string;
    set celMatch(value: string);
    get celMatchInput(): string | undefined;
    get createTime(): string;
    private _destination?;
    get destination(): string;
    set destination(value: string);
    get destinationInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _enrollmentId?;
    get enrollmentId(): string;
    set enrollmentId(value: string);
    get enrollmentIdInput(): string | undefined;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _messageBus?;
    get messageBus(): string;
    set messageBus(value: string);
    get messageBusInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): EventarcEnrollmentTimeoutsOutputReference;
    putTimeouts(value: EventarcEnrollmentTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | EventarcEnrollmentTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
