/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface FirebaseAppHostingBuildConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unstructured key value map that may be set by external tools to
    * store and arbitrary metadata. They are not queryable and should be
    * preserved when modifying objects.
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#annotations FirebaseAppHostingBuild#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * The ID of the Backend that this Build applies to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#backend FirebaseAppHostingBuild#backend}
    */
    readonly backend: string;
    /**
    * The user-specified ID of the build being created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#build_id FirebaseAppHostingBuild#build_id}
    */
    readonly buildId: string;
    /**
    * Human-readable name. 63 character limit.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#display_name FirebaseAppHostingBuild#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#id FirebaseAppHostingBuild#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unstructured key value map that can be used to organize and categorize
    * objects.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#labels FirebaseAppHostingBuild#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location of the Backend that this Build applies to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#location FirebaseAppHostingBuild#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#project FirebaseAppHostingBuild#project}
    */
    readonly project?: string;
    /**
    * source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#source FirebaseAppHostingBuild#source}
    */
    readonly source: FirebaseAppHostingBuildSource;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#timeouts FirebaseAppHostingBuild#timeouts}
    */
    readonly timeouts?: FirebaseAppHostingBuildTimeouts;
}
export interface FirebaseAppHostingBuildError {
}
export declare function firebaseAppHostingBuildErrorToTerraform(struct?: FirebaseAppHostingBuildError): any;
export declare function firebaseAppHostingBuildErrorToHclTerraform(struct?: FirebaseAppHostingBuildError): any;
export declare class FirebaseAppHostingBuildErrorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): FirebaseAppHostingBuildError | undefined;
    set internalValue(value: FirebaseAppHostingBuildError | undefined);
    get code(): number;
    private _details;
    get details(): cdktf.StringMapList;
    get message(): string;
}
export declare class FirebaseAppHostingBuildErrorList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): FirebaseAppHostingBuildErrorOutputReference;
}
export interface FirebaseAppHostingBuildSourceCodebaseAuthor {
}
export declare function firebaseAppHostingBuildSourceCodebaseAuthorToTerraform(struct?: FirebaseAppHostingBuildSourceCodebaseAuthor): any;
export declare function firebaseAppHostingBuildSourceCodebaseAuthorToHclTerraform(struct?: FirebaseAppHostingBuildSourceCodebaseAuthor): any;
export declare class FirebaseAppHostingBuildSourceCodebaseAuthorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): FirebaseAppHostingBuildSourceCodebaseAuthor | undefined;
    set internalValue(value: FirebaseAppHostingBuildSourceCodebaseAuthor | undefined);
    get displayName(): string;
    get email(): string;
    get imageUri(): string;
}
export declare class FirebaseAppHostingBuildSourceCodebaseAuthorList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): FirebaseAppHostingBuildSourceCodebaseAuthorOutputReference;
}
export interface FirebaseAppHostingBuildSourceCodebase {
    /**
    * The branch in the codebase to build from, using the latest commit.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#branch FirebaseAppHostingBuild#branch}
    */
    readonly branch?: string;
    /**
    * The commit in the codebase to build from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#commit FirebaseAppHostingBuild#commit}
    */
    readonly commit?: string;
}
export declare function firebaseAppHostingBuildSourceCodebaseToTerraform(struct?: FirebaseAppHostingBuildSourceCodebaseOutputReference | FirebaseAppHostingBuildSourceCodebase): any;
export declare function firebaseAppHostingBuildSourceCodebaseToHclTerraform(struct?: FirebaseAppHostingBuildSourceCodebaseOutputReference | FirebaseAppHostingBuildSourceCodebase): any;
export declare class FirebaseAppHostingBuildSourceCodebaseOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FirebaseAppHostingBuildSourceCodebase | undefined;
    set internalValue(value: FirebaseAppHostingBuildSourceCodebase | undefined);
    private _author;
    get author(): FirebaseAppHostingBuildSourceCodebaseAuthorList;
    private _branch?;
    get branch(): string;
    set branch(value: string);
    resetBranch(): void;
    get branchInput(): string | undefined;
    private _commit?;
    get commit(): string;
    set commit(value: string);
    resetCommit(): void;
    get commitInput(): string | undefined;
    get commitMessage(): string;
    get commitTime(): string;
    get displayName(): string;
    get hash(): string;
    get uri(): string;
}
export interface FirebaseAppHostingBuildSourceContainer {
    /**
    * A URI representing a container for the backend to use.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#image FirebaseAppHostingBuild#image}
    */
    readonly image: string;
}
export declare function firebaseAppHostingBuildSourceContainerToTerraform(struct?: FirebaseAppHostingBuildSourceContainerOutputReference | FirebaseAppHostingBuildSourceContainer): any;
export declare function firebaseAppHostingBuildSourceContainerToHclTerraform(struct?: FirebaseAppHostingBuildSourceContainerOutputReference | FirebaseAppHostingBuildSourceContainer): any;
export declare class FirebaseAppHostingBuildSourceContainerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FirebaseAppHostingBuildSourceContainer | undefined;
    set internalValue(value: FirebaseAppHostingBuildSourceContainer | undefined);
    private _image?;
    get image(): string;
    set image(value: string);
    get imageInput(): string | undefined;
}
export interface FirebaseAppHostingBuildSource {
    /**
    * codebase block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#codebase FirebaseAppHostingBuild#codebase}
    */
    readonly codebase?: FirebaseAppHostingBuildSourceCodebase;
    /**
    * container block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#container FirebaseAppHostingBuild#container}
    */
    readonly container?: FirebaseAppHostingBuildSourceContainer;
}
export declare function firebaseAppHostingBuildSourceToTerraform(struct?: FirebaseAppHostingBuildSourceOutputReference | FirebaseAppHostingBuildSource): any;
export declare function firebaseAppHostingBuildSourceToHclTerraform(struct?: FirebaseAppHostingBuildSourceOutputReference | FirebaseAppHostingBuildSource): any;
export declare class FirebaseAppHostingBuildSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FirebaseAppHostingBuildSource | undefined;
    set internalValue(value: FirebaseAppHostingBuildSource | undefined);
    private _codebase;
    get codebase(): FirebaseAppHostingBuildSourceCodebaseOutputReference;
    putCodebase(value: FirebaseAppHostingBuildSourceCodebase): void;
    resetCodebase(): void;
    get codebaseInput(): FirebaseAppHostingBuildSourceCodebase | undefined;
    private _container;
    get container(): FirebaseAppHostingBuildSourceContainerOutputReference;
    putContainer(value: FirebaseAppHostingBuildSourceContainer): void;
    resetContainer(): void;
    get containerInput(): FirebaseAppHostingBuildSourceContainer | undefined;
}
export interface FirebaseAppHostingBuildTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#create FirebaseAppHostingBuild#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#delete FirebaseAppHostingBuild#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#update FirebaseAppHostingBuild#update}
    */
    readonly update?: string;
}
export declare function firebaseAppHostingBuildTimeoutsToTerraform(struct?: FirebaseAppHostingBuildTimeouts | cdktf.IResolvable): any;
export declare function firebaseAppHostingBuildTimeoutsToHclTerraform(struct?: FirebaseAppHostingBuildTimeouts | cdktf.IResolvable): any;
export declare class FirebaseAppHostingBuildTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FirebaseAppHostingBuildTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: FirebaseAppHostingBuildTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build google_firebase_app_hosting_build}
*/
export declare class FirebaseAppHostingBuild extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_firebase_app_hosting_build";
    /**
    * Generates CDKTF code for importing a FirebaseAppHostingBuild resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the FirebaseAppHostingBuild to import
    * @param importFromId The id of the existing FirebaseAppHostingBuild that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the FirebaseAppHostingBuild to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/firebase_app_hosting_build google_firebase_app_hosting_build} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options FirebaseAppHostingBuildConfig
    */
    constructor(scope: Construct, id: string, config: FirebaseAppHostingBuildConfig);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    private _backend?;
    get backend(): string;
    set backend(value: string);
    get backendInput(): string | undefined;
    private _buildId?;
    get buildId(): string;
    set buildId(value: string);
    get buildIdInput(): string | undefined;
    get buildLogsUri(): string;
    get createTime(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get environment(): string;
    private _error;
    get error(): FirebaseAppHostingBuildErrorList;
    get errorSource(): string;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get image(): string;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _source;
    get source(): FirebaseAppHostingBuildSourceOutputReference;
    putSource(value: FirebaseAppHostingBuildSource): void;
    get sourceInput(): FirebaseAppHostingBuildSource | undefined;
    private _timeouts;
    get timeouts(): FirebaseAppHostingBuildTimeoutsOutputReference;
    putTimeouts(value: FirebaseAppHostingBuildTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | FirebaseAppHostingBuildTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
