/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GeminiCodeToolsSettingConfig extends cdktf.TerraformMetaArguments {
    /**
    * Id of the Code Tools Setting.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#code_tools_setting_id GeminiCodeToolsSetting#code_tools_setting_id}
    */
    readonly codeToolsSettingId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#id GeminiCodeToolsSetting#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Labels as key value pairs.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#labels GeminiCodeToolsSetting#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Resource ID segment making up resource 'name'. It identifies the resource within its parent collection as described in https://google.aip.dev/122.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#location GeminiCodeToolsSetting#location}
    */
    readonly location?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#project GeminiCodeToolsSetting#project}
    */
    readonly project?: string;
    /**
    * enabled_tool block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#enabled_tool GeminiCodeToolsSetting#enabled_tool}
    */
    readonly enabledTool: GeminiCodeToolsSettingEnabledTool[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#timeouts GeminiCodeToolsSetting#timeouts}
    */
    readonly timeouts?: GeminiCodeToolsSettingTimeouts;
}
export interface GeminiCodeToolsSettingEnabledToolConfig {
    /**
    * Key of the configuration item.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#key GeminiCodeToolsSetting#key}
    */
    readonly key: string;
    /**
    * Value of the configuration item.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#value GeminiCodeToolsSetting#value}
    */
    readonly value: string;
}
export declare function geminiCodeToolsSettingEnabledToolConfigToTerraform(struct?: GeminiCodeToolsSettingEnabledToolConfig | cdktf.IResolvable): any;
export declare function geminiCodeToolsSettingEnabledToolConfigToHclTerraform(struct?: GeminiCodeToolsSettingEnabledToolConfig | cdktf.IResolvable): any;
export declare class GeminiCodeToolsSettingEnabledToolConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GeminiCodeToolsSettingEnabledToolConfig | cdktf.IResolvable | undefined;
    set internalValue(value: GeminiCodeToolsSettingEnabledToolConfig | cdktf.IResolvable | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class GeminiCodeToolsSettingEnabledToolConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GeminiCodeToolsSettingEnabledToolConfig[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GeminiCodeToolsSettingEnabledToolConfigOutputReference;
}
export interface GeminiCodeToolsSettingEnabledTool {
    /**
    * Link to the Dev Connect Account Connector that holds the user credentials.
    * projects/{project}/locations/{location}/accountConnectors/{account_connector_id}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#account_connector GeminiCodeToolsSetting#account_connector}
    */
    readonly accountConnector?: string;
    /**
    * Handle used to invoke the tool.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#handle GeminiCodeToolsSetting#handle}
    */
    readonly handle: string;
    /**
    * Link to the Tool
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#tool GeminiCodeToolsSetting#tool}
    */
    readonly tool: string;
    /**
    * Overridden URI, if allowed by Tool.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#uri_override GeminiCodeToolsSetting#uri_override}
    */
    readonly uriOverride?: string;
    /**
    * config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#config GeminiCodeToolsSetting#config}
    */
    readonly config?: GeminiCodeToolsSettingEnabledToolConfig[] | cdktf.IResolvable;
}
export declare function geminiCodeToolsSettingEnabledToolToTerraform(struct?: GeminiCodeToolsSettingEnabledTool | cdktf.IResolvable): any;
export declare function geminiCodeToolsSettingEnabledToolToHclTerraform(struct?: GeminiCodeToolsSettingEnabledTool | cdktf.IResolvable): any;
export declare class GeminiCodeToolsSettingEnabledToolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GeminiCodeToolsSettingEnabledTool | cdktf.IResolvable | undefined;
    set internalValue(value: GeminiCodeToolsSettingEnabledTool | cdktf.IResolvable | undefined);
    private _accountConnector?;
    get accountConnector(): string;
    set accountConnector(value: string);
    resetAccountConnector(): void;
    get accountConnectorInput(): string | undefined;
    private _handle?;
    get handle(): string;
    set handle(value: string);
    get handleInput(): string | undefined;
    private _tool?;
    get tool(): string;
    set tool(value: string);
    get toolInput(): string | undefined;
    private _uriOverride?;
    get uriOverride(): string;
    set uriOverride(value: string);
    resetUriOverride(): void;
    get uriOverrideInput(): string | undefined;
    private _config;
    get config(): GeminiCodeToolsSettingEnabledToolConfigList;
    putConfig(value: GeminiCodeToolsSettingEnabledToolConfig[] | cdktf.IResolvable): void;
    resetConfig(): void;
    get configInput(): cdktf.IResolvable | GeminiCodeToolsSettingEnabledToolConfig[] | undefined;
}
export declare class GeminiCodeToolsSettingEnabledToolList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GeminiCodeToolsSettingEnabledTool[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GeminiCodeToolsSettingEnabledToolOutputReference;
}
export interface GeminiCodeToolsSettingTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#create GeminiCodeToolsSetting#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#delete GeminiCodeToolsSetting#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#update GeminiCodeToolsSetting#update}
    */
    readonly update?: string;
}
export declare function geminiCodeToolsSettingTimeoutsToTerraform(struct?: GeminiCodeToolsSettingTimeouts | cdktf.IResolvable): any;
export declare function geminiCodeToolsSettingTimeoutsToHclTerraform(struct?: GeminiCodeToolsSettingTimeouts | cdktf.IResolvable): any;
export declare class GeminiCodeToolsSettingTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GeminiCodeToolsSettingTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GeminiCodeToolsSettingTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting google_gemini_code_tools_setting}
*/
export declare class GeminiCodeToolsSetting extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_gemini_code_tools_setting";
    /**
    * Generates CDKTF code for importing a GeminiCodeToolsSetting resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GeminiCodeToolsSetting to import
    * @param importFromId The id of the existing GeminiCodeToolsSetting that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GeminiCodeToolsSetting to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/gemini_code_tools_setting google_gemini_code_tools_setting} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GeminiCodeToolsSettingConfig
    */
    constructor(scope: Construct, id: string, config: GeminiCodeToolsSettingConfig);
    private _codeToolsSettingId?;
    get codeToolsSettingId(): string;
    set codeToolsSettingId(value: string);
    get codeToolsSettingIdInput(): string | undefined;
    get createTime(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _enabledTool;
    get enabledTool(): GeminiCodeToolsSettingEnabledToolList;
    putEnabledTool(value: GeminiCodeToolsSettingEnabledTool[] | cdktf.IResolvable): void;
    get enabledToolInput(): cdktf.IResolvable | GeminiCodeToolsSettingEnabledTool[] | undefined;
    private _timeouts;
    get timeouts(): GeminiCodeToolsSettingTimeoutsOutputReference;
    putTimeouts(value: GeminiCodeToolsSettingTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GeminiCodeToolsSettingTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
