/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface LustreInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Required. The storage capacity of the instance in gibibytes (GiB). Allowed values
    * are from 18000 to 954000, in increments of 9000.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#capacity_gib LustreInstance#capacity_gib}
    */
    readonly capacityGib: string;
    /**
    * Optional. A user-readable description of the instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#description LustreInstance#description}
    */
    readonly description?: string;
    /**
    * Required. Immutable. The filesystem name for this instance. This name is used by client-side
    * tools, including when mounting the instance. Must be 8 characters or less
    * and may only contain letters and numbers.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#filesystem LustreInstance#filesystem}
    */
    readonly filesystem: string;
    /**
    * Optional. Indicates whether you want to enable support for GKE clients. By default,
    * GKE clients are not supported.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#gke_support_enabled LustreInstance#gke_support_enabled}
    */
    readonly gkeSupportEnabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#id LustreInstance#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Required. The name of the Managed Lustre instance.
    *
    * * Must contain only lowercase letters, numbers, and hyphens.
    * * Must start with a letter.
    * * Must be between 1-63 characters.
    * * Must end with a number or a letter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#instance_id LustreInstance#instance_id}
    */
    readonly instanceId: string;
    /**
    * Optional. Labels as key value pairs.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#labels LustreInstance#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Resource ID segment making up resource 'name'. It identifies the resource within its parent collection as described in https://google.aip.dev/122.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#location LustreInstance#location}
    */
    readonly location: string;
    /**
    * Required. Immutable. The full name of the VPC network to which the instance is connected.
    * Must be in the format
    * 'projects/{project_id}/global/networks/{network_name}'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#network LustreInstance#network}
    */
    readonly network: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#project LustreInstance#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#timeouts LustreInstance#timeouts}
    */
    readonly timeouts?: LustreInstanceTimeouts;
}
export interface LustreInstanceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#create LustreInstance#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#delete LustreInstance#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#update LustreInstance#update}
    */
    readonly update?: string;
}
export declare function lustreInstanceTimeoutsToTerraform(struct?: LustreInstanceTimeouts | cdktf.IResolvable): any;
export declare function lustreInstanceTimeoutsToHclTerraform(struct?: LustreInstanceTimeouts | cdktf.IResolvable): any;
export declare class LustreInstanceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): LustreInstanceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: LustreInstanceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance google_lustre_instance}
*/
export declare class LustreInstance extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_lustre_instance";
    /**
    * Generates CDKTF code for importing a LustreInstance resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the LustreInstance to import
    * @param importFromId The id of the existing LustreInstance that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the LustreInstance to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/lustre_instance google_lustre_instance} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options LustreInstanceConfig
    */
    constructor(scope: Construct, id: string, config: LustreInstanceConfig);
    private _capacityGib?;
    get capacityGib(): string;
    set capacityGib(value: string);
    get capacityGibInput(): string | undefined;
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _filesystem?;
    get filesystem(): string;
    set filesystem(value: string);
    get filesystemInput(): string | undefined;
    private _gkeSupportEnabled?;
    get gkeSupportEnabled(): boolean | cdktf.IResolvable;
    set gkeSupportEnabled(value: boolean | cdktf.IResolvable);
    resetGkeSupportEnabled(): void;
    get gkeSupportEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _instanceId?;
    get instanceId(): string;
    set instanceId(value: string);
    get instanceIdInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get mountPoint(): string;
    get name(): string;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): LustreInstanceTimeoutsOutputReference;
    putTimeouts(value: LustreInstanceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | LustreInstanceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
