/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface StorageControlFolderIntelligenceConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edition configuration of the Storage Intelligence resource. Valid values are INHERIT, TRIAL, DISABLED and STANDARD.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#edition_config StorageControlFolderIntelligenceConfig#edition_config}
    */
    readonly editionConfig?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#id StorageControlFolderIntelligenceConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Identifier of the GCP Folder. For GCP Folder, this field can be folder number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#name StorageControlFolderIntelligenceConfig#name}
    */
    readonly name: string;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#filter StorageControlFolderIntelligenceConfig#filter}
    */
    readonly filter?: StorageControlFolderIntelligenceConfigFilter;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#timeouts StorageControlFolderIntelligenceConfig#timeouts}
    */
    readonly timeouts?: StorageControlFolderIntelligenceConfigTimeouts;
}
export interface StorageControlFolderIntelligenceConfigEffectiveIntelligenceConfig {
}
export declare function storageControlFolderIntelligenceConfigEffectiveIntelligenceConfigToTerraform(struct?: StorageControlFolderIntelligenceConfigEffectiveIntelligenceConfig): any;
export declare function storageControlFolderIntelligenceConfigEffectiveIntelligenceConfigToHclTerraform(struct?: StorageControlFolderIntelligenceConfigEffectiveIntelligenceConfig): any;
export declare class StorageControlFolderIntelligenceConfigEffectiveIntelligenceConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): StorageControlFolderIntelligenceConfigEffectiveIntelligenceConfig | undefined;
    set internalValue(value: StorageControlFolderIntelligenceConfigEffectiveIntelligenceConfig | undefined);
    get effectiveEdition(): string;
    get intelligenceConfig(): string;
}
export declare class StorageControlFolderIntelligenceConfigEffectiveIntelligenceConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): StorageControlFolderIntelligenceConfigEffectiveIntelligenceConfigOutputReference;
}
export interface StorageControlFolderIntelligenceConfigTrialConfig {
}
export declare function storageControlFolderIntelligenceConfigTrialConfigToTerraform(struct?: StorageControlFolderIntelligenceConfigTrialConfig): any;
export declare function storageControlFolderIntelligenceConfigTrialConfigToHclTerraform(struct?: StorageControlFolderIntelligenceConfigTrialConfig): any;
export declare class StorageControlFolderIntelligenceConfigTrialConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): StorageControlFolderIntelligenceConfigTrialConfig | undefined;
    set internalValue(value: StorageControlFolderIntelligenceConfigTrialConfig | undefined);
    get expireTime(): string;
}
export declare class StorageControlFolderIntelligenceConfigTrialConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): StorageControlFolderIntelligenceConfigTrialConfigOutputReference;
}
export interface StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets {
    /**
    * List of bucket id regexes to exclude in the storage intelligence plan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#bucket_id_regexes StorageControlFolderIntelligenceConfig#bucket_id_regexes}
    */
    readonly bucketIdRegexes: string[];
}
export declare function storageControlFolderIntelligenceConfigFilterExcludedCloudStorageBucketsToTerraform(struct?: StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference | StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets): any;
export declare function storageControlFolderIntelligenceConfigFilterExcludedCloudStorageBucketsToHclTerraform(struct?: StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference | StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets): any;
export declare class StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined;
    set internalValue(value: StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined);
    private _bucketIdRegexes?;
    get bucketIdRegexes(): string[];
    set bucketIdRegexes(value: string[]);
    get bucketIdRegexesInput(): string[] | undefined;
}
export interface StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations {
    /**
    * List of locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#locations StorageControlFolderIntelligenceConfig#locations}
    */
    readonly locations: string[];
}
export declare function storageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocationsToTerraform(struct?: StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference | StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations): any;
export declare function storageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocationsToHclTerraform(struct?: StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference | StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations): any;
export declare class StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations | undefined;
    set internalValue(value: StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations | undefined);
    private _locations?;
    get locations(): string[];
    set locations(value: string[]);
    get locationsInput(): string[] | undefined;
}
export interface StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets {
    /**
    * List of bucket id regexes to exclude in the storage intelligence plan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#bucket_id_regexes StorageControlFolderIntelligenceConfig#bucket_id_regexes}
    */
    readonly bucketIdRegexes: string[];
}
export declare function storageControlFolderIntelligenceConfigFilterIncludedCloudStorageBucketsToTerraform(struct?: StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference | StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets): any;
export declare function storageControlFolderIntelligenceConfigFilterIncludedCloudStorageBucketsToHclTerraform(struct?: StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference | StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets): any;
export declare class StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined;
    set internalValue(value: StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined);
    private _bucketIdRegexes?;
    get bucketIdRegexes(): string[];
    set bucketIdRegexes(value: string[]);
    get bucketIdRegexesInput(): string[] | undefined;
}
export interface StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations {
    /**
    * List of locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#locations StorageControlFolderIntelligenceConfig#locations}
    */
    readonly locations: string[];
}
export declare function storageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocationsToTerraform(struct?: StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference | StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations): any;
export declare function storageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocationsToHclTerraform(struct?: StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference | StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations): any;
export declare class StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations | undefined;
    set internalValue(value: StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations | undefined);
    private _locations?;
    get locations(): string[];
    set locations(value: string[]);
    get locationsInput(): string[] | undefined;
}
export interface StorageControlFolderIntelligenceConfigFilter {
    /**
    * excluded_cloud_storage_buckets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#excluded_cloud_storage_buckets StorageControlFolderIntelligenceConfig#excluded_cloud_storage_buckets}
    */
    readonly excludedCloudStorageBuckets?: StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets;
    /**
    * excluded_cloud_storage_locations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#excluded_cloud_storage_locations StorageControlFolderIntelligenceConfig#excluded_cloud_storage_locations}
    */
    readonly excludedCloudStorageLocations?: StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations;
    /**
    * included_cloud_storage_buckets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#included_cloud_storage_buckets StorageControlFolderIntelligenceConfig#included_cloud_storage_buckets}
    */
    readonly includedCloudStorageBuckets?: StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets;
    /**
    * included_cloud_storage_locations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#included_cloud_storage_locations StorageControlFolderIntelligenceConfig#included_cloud_storage_locations}
    */
    readonly includedCloudStorageLocations?: StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations;
}
export declare function storageControlFolderIntelligenceConfigFilterToTerraform(struct?: StorageControlFolderIntelligenceConfigFilterOutputReference | StorageControlFolderIntelligenceConfigFilter): any;
export declare function storageControlFolderIntelligenceConfigFilterToHclTerraform(struct?: StorageControlFolderIntelligenceConfigFilterOutputReference | StorageControlFolderIntelligenceConfigFilter): any;
export declare class StorageControlFolderIntelligenceConfigFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StorageControlFolderIntelligenceConfigFilter | undefined;
    set internalValue(value: StorageControlFolderIntelligenceConfigFilter | undefined);
    private _excludedCloudStorageBuckets;
    get excludedCloudStorageBuckets(): StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference;
    putExcludedCloudStorageBuckets(value: StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets): void;
    resetExcludedCloudStorageBuckets(): void;
    get excludedCloudStorageBucketsInput(): StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined;
    private _excludedCloudStorageLocations;
    get excludedCloudStorageLocations(): StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference;
    putExcludedCloudStorageLocations(value: StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations): void;
    resetExcludedCloudStorageLocations(): void;
    get excludedCloudStorageLocationsInput(): StorageControlFolderIntelligenceConfigFilterExcludedCloudStorageLocations | undefined;
    private _includedCloudStorageBuckets;
    get includedCloudStorageBuckets(): StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference;
    putIncludedCloudStorageBuckets(value: StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets): void;
    resetIncludedCloudStorageBuckets(): void;
    get includedCloudStorageBucketsInput(): StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined;
    private _includedCloudStorageLocations;
    get includedCloudStorageLocations(): StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference;
    putIncludedCloudStorageLocations(value: StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations): void;
    resetIncludedCloudStorageLocations(): void;
    get includedCloudStorageLocationsInput(): StorageControlFolderIntelligenceConfigFilterIncludedCloudStorageLocations | undefined;
}
export interface StorageControlFolderIntelligenceConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#create StorageControlFolderIntelligenceConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#delete StorageControlFolderIntelligenceConfig#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#update StorageControlFolderIntelligenceConfig#update}
    */
    readonly update?: string;
}
export declare function storageControlFolderIntelligenceConfigTimeoutsToTerraform(struct?: StorageControlFolderIntelligenceConfigTimeouts | cdktf.IResolvable): any;
export declare function storageControlFolderIntelligenceConfigTimeoutsToHclTerraform(struct?: StorageControlFolderIntelligenceConfigTimeouts | cdktf.IResolvable): any;
export declare class StorageControlFolderIntelligenceConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StorageControlFolderIntelligenceConfigTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: StorageControlFolderIntelligenceConfigTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config google_storage_control_folder_intelligence_config}
*/
export declare class StorageControlFolderIntelligenceConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_storage_control_folder_intelligence_config";
    /**
    * Generates CDKTF code for importing a StorageControlFolderIntelligenceConfig resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the StorageControlFolderIntelligenceConfig to import
    * @param importFromId The id of the existing StorageControlFolderIntelligenceConfig that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the StorageControlFolderIntelligenceConfig to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_folder_intelligence_config google_storage_control_folder_intelligence_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options StorageControlFolderIntelligenceConfigConfig
    */
    constructor(scope: Construct, id: string, config: StorageControlFolderIntelligenceConfigConfig);
    private _editionConfig?;
    get editionConfig(): string;
    set editionConfig(value: string);
    resetEditionConfig(): void;
    get editionConfigInput(): string | undefined;
    private _effectiveIntelligenceConfig;
    get effectiveIntelligenceConfig(): StorageControlFolderIntelligenceConfigEffectiveIntelligenceConfigList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _trialConfig;
    get trialConfig(): StorageControlFolderIntelligenceConfigTrialConfigList;
    get updateTime(): string;
    private _filter;
    get filter(): StorageControlFolderIntelligenceConfigFilterOutputReference;
    putFilter(value: StorageControlFolderIntelligenceConfigFilter): void;
    resetFilter(): void;
    get filterInput(): StorageControlFolderIntelligenceConfigFilter | undefined;
    private _timeouts;
    get timeouts(): StorageControlFolderIntelligenceConfigTimeoutsOutputReference;
    putTimeouts(value: StorageControlFolderIntelligenceConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | StorageControlFolderIntelligenceConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
