/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface StorageControlOrganizationIntelligenceConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edition configuration of the Storage Intelligence resource. Valid values are INHERIT, DISABLED, TRIAL and STANDARD.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#edition_config StorageControlOrganizationIntelligenceConfig#edition_config}
    */
    readonly editionConfig?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#id StorageControlOrganizationIntelligenceConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Identifier of the GCP Organization. For GCP org, this field should be organization number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#name StorageControlOrganizationIntelligenceConfig#name}
    */
    readonly name: string;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#filter StorageControlOrganizationIntelligenceConfig#filter}
    */
    readonly filter?: StorageControlOrganizationIntelligenceConfigFilter;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#timeouts StorageControlOrganizationIntelligenceConfig#timeouts}
    */
    readonly timeouts?: StorageControlOrganizationIntelligenceConfigTimeouts;
}
export interface StorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfig {
}
export declare function storageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfigToTerraform(struct?: StorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfig): any;
export declare function storageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfigToHclTerraform(struct?: StorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfig): any;
export declare class StorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): StorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfig | undefined;
    set internalValue(value: StorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfig | undefined);
    get effectiveEdition(): string;
    get intelligenceConfig(): string;
}
export declare class StorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): StorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfigOutputReference;
}
export interface StorageControlOrganizationIntelligenceConfigTrialConfig {
}
export declare function storageControlOrganizationIntelligenceConfigTrialConfigToTerraform(struct?: StorageControlOrganizationIntelligenceConfigTrialConfig): any;
export declare function storageControlOrganizationIntelligenceConfigTrialConfigToHclTerraform(struct?: StorageControlOrganizationIntelligenceConfigTrialConfig): any;
export declare class StorageControlOrganizationIntelligenceConfigTrialConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): StorageControlOrganizationIntelligenceConfigTrialConfig | undefined;
    set internalValue(value: StorageControlOrganizationIntelligenceConfigTrialConfig | undefined);
    get expireTime(): string;
}
export declare class StorageControlOrganizationIntelligenceConfigTrialConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): StorageControlOrganizationIntelligenceConfigTrialConfigOutputReference;
}
export interface StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets {
    /**
    * List of bucket id regexes to exclude in the storage intelligence plan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#bucket_id_regexes StorageControlOrganizationIntelligenceConfig#bucket_id_regexes}
    */
    readonly bucketIdRegexes: string[];
}
export declare function storageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBucketsToTerraform(struct?: StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference | StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets): any;
export declare function storageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBucketsToHclTerraform(struct?: StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference | StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets): any;
export declare class StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined;
    set internalValue(value: StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined);
    private _bucketIdRegexes?;
    get bucketIdRegexes(): string[];
    set bucketIdRegexes(value: string[]);
    get bucketIdRegexesInput(): string[] | undefined;
}
export interface StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations {
    /**
    * List of locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#locations StorageControlOrganizationIntelligenceConfig#locations}
    */
    readonly locations: string[];
}
export declare function storageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocationsToTerraform(struct?: StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference | StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations): any;
export declare function storageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocationsToHclTerraform(struct?: StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference | StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations): any;
export declare class StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations | undefined;
    set internalValue(value: StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations | undefined);
    private _locations?;
    get locations(): string[];
    set locations(value: string[]);
    get locationsInput(): string[] | undefined;
}
export interface StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets {
    /**
    * List of bucket id regexes to exclude in the storage intelligence plan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#bucket_id_regexes StorageControlOrganizationIntelligenceConfig#bucket_id_regexes}
    */
    readonly bucketIdRegexes: string[];
}
export declare function storageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBucketsToTerraform(struct?: StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference | StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets): any;
export declare function storageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBucketsToHclTerraform(struct?: StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference | StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets): any;
export declare class StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined;
    set internalValue(value: StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined);
    private _bucketIdRegexes?;
    get bucketIdRegexes(): string[];
    set bucketIdRegexes(value: string[]);
    get bucketIdRegexesInput(): string[] | undefined;
}
export interface StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations {
    /**
    * List of locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#locations StorageControlOrganizationIntelligenceConfig#locations}
    */
    readonly locations: string[];
}
export declare function storageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocationsToTerraform(struct?: StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference | StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations): any;
export declare function storageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocationsToHclTerraform(struct?: StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference | StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations): any;
export declare class StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations | undefined;
    set internalValue(value: StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations | undefined);
    private _locations?;
    get locations(): string[];
    set locations(value: string[]);
    get locationsInput(): string[] | undefined;
}
export interface StorageControlOrganizationIntelligenceConfigFilter {
    /**
    * excluded_cloud_storage_buckets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#excluded_cloud_storage_buckets StorageControlOrganizationIntelligenceConfig#excluded_cloud_storage_buckets}
    */
    readonly excludedCloudStorageBuckets?: StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets;
    /**
    * excluded_cloud_storage_locations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#excluded_cloud_storage_locations StorageControlOrganizationIntelligenceConfig#excluded_cloud_storage_locations}
    */
    readonly excludedCloudStorageLocations?: StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations;
    /**
    * included_cloud_storage_buckets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#included_cloud_storage_buckets StorageControlOrganizationIntelligenceConfig#included_cloud_storage_buckets}
    */
    readonly includedCloudStorageBuckets?: StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets;
    /**
    * included_cloud_storage_locations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#included_cloud_storage_locations StorageControlOrganizationIntelligenceConfig#included_cloud_storage_locations}
    */
    readonly includedCloudStorageLocations?: StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations;
}
export declare function storageControlOrganizationIntelligenceConfigFilterToTerraform(struct?: StorageControlOrganizationIntelligenceConfigFilterOutputReference | StorageControlOrganizationIntelligenceConfigFilter): any;
export declare function storageControlOrganizationIntelligenceConfigFilterToHclTerraform(struct?: StorageControlOrganizationIntelligenceConfigFilterOutputReference | StorageControlOrganizationIntelligenceConfigFilter): any;
export declare class StorageControlOrganizationIntelligenceConfigFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StorageControlOrganizationIntelligenceConfigFilter | undefined;
    set internalValue(value: StorageControlOrganizationIntelligenceConfigFilter | undefined);
    private _excludedCloudStorageBuckets;
    get excludedCloudStorageBuckets(): StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference;
    putExcludedCloudStorageBuckets(value: StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets): void;
    resetExcludedCloudStorageBuckets(): void;
    get excludedCloudStorageBucketsInput(): StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined;
    private _excludedCloudStorageLocations;
    get excludedCloudStorageLocations(): StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference;
    putExcludedCloudStorageLocations(value: StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations): void;
    resetExcludedCloudStorageLocations(): void;
    get excludedCloudStorageLocationsInput(): StorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations | undefined;
    private _includedCloudStorageBuckets;
    get includedCloudStorageBuckets(): StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference;
    putIncludedCloudStorageBuckets(value: StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets): void;
    resetIncludedCloudStorageBuckets(): void;
    get includedCloudStorageBucketsInput(): StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined;
    private _includedCloudStorageLocations;
    get includedCloudStorageLocations(): StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference;
    putIncludedCloudStorageLocations(value: StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations): void;
    resetIncludedCloudStorageLocations(): void;
    get includedCloudStorageLocationsInput(): StorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations | undefined;
}
export interface StorageControlOrganizationIntelligenceConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#create StorageControlOrganizationIntelligenceConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#delete StorageControlOrganizationIntelligenceConfig#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#update StorageControlOrganizationIntelligenceConfig#update}
    */
    readonly update?: string;
}
export declare function storageControlOrganizationIntelligenceConfigTimeoutsToTerraform(struct?: StorageControlOrganizationIntelligenceConfigTimeouts | cdktf.IResolvable): any;
export declare function storageControlOrganizationIntelligenceConfigTimeoutsToHclTerraform(struct?: StorageControlOrganizationIntelligenceConfigTimeouts | cdktf.IResolvable): any;
export declare class StorageControlOrganizationIntelligenceConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StorageControlOrganizationIntelligenceConfigTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: StorageControlOrganizationIntelligenceConfigTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config google_storage_control_organization_intelligence_config}
*/
export declare class StorageControlOrganizationIntelligenceConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_storage_control_organization_intelligence_config";
    /**
    * Generates CDKTF code for importing a StorageControlOrganizationIntelligenceConfig resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the StorageControlOrganizationIntelligenceConfig to import
    * @param importFromId The id of the existing StorageControlOrganizationIntelligenceConfig that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the StorageControlOrganizationIntelligenceConfig to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/storage_control_organization_intelligence_config google_storage_control_organization_intelligence_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options StorageControlOrganizationIntelligenceConfigConfig
    */
    constructor(scope: Construct, id: string, config: StorageControlOrganizationIntelligenceConfigConfig);
    private _editionConfig?;
    get editionConfig(): string;
    set editionConfig(value: string);
    resetEditionConfig(): void;
    get editionConfigInput(): string | undefined;
    private _effectiveIntelligenceConfig;
    get effectiveIntelligenceConfig(): StorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfigList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _trialConfig;
    get trialConfig(): StorageControlOrganizationIntelligenceConfigTrialConfigList;
    get updateTime(): string;
    private _filter;
    get filter(): StorageControlOrganizationIntelligenceConfigFilterOutputReference;
    putFilter(value: StorageControlOrganizationIntelligenceConfigFilter): void;
    resetFilter(): void;
    get filterInput(): StorageControlOrganizationIntelligenceConfigFilter | undefined;
    private _timeouts;
    get timeouts(): StorageControlOrganizationIntelligenceConfigTimeoutsOutputReference;
    putTimeouts(value: StorageControlOrganizationIntelligenceConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | StorageControlOrganizationIntelligenceConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
